@@ -1573,18 +1573,6 @@ srl_read_reserved(pTHX_ srl_decoder_t *dec, U8 tag, SV* into)
     sv_setsv(into, &PL_sv_undef);
 }
 
-#if ((PERL_VERSION > 10) || (PERL_VERSION == 10 && PERL_SUBVERSION > 1 ))
-#   define MODERN_REGEXP
-#   define REGEXP_HAS_P_MODIFIER
-#   pragma message ( "MODERN_REGEXP" )
-#elif PERL_VERSION == 10
-#   define TRANSITION_REGEXP
-#   define REGEXP_HAS_P_MODIFIER
-#   pragma message ( "TRANSITION_REGEXP" )
-#else
-#   define OLD_REGEXP
-#   pragma message ( "OLD_REGEXP" )
-#endif
 
 SRL_STATIC_INLINE void
 srl_read_regexp(pTHX_ srl_decoder_t *dec, SV* into)
